==> haskell-hedgehog-1.4-53-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hedgehog
version:              1.4
visibility:           public
id:                   hedgehog-1.4-1tCtDh3TfwVEMNETK0R6iC
key:                  hedgehog-1.4-1tCtDh3TfwVEMNETK0R6iC
license:              BSD-3-Clause
maintainer:           Jacob Stanley <jacob@stanley.io>
author:               Jacob Stanley
homepage:             https://hedgehog.qa
synopsis:             Release with confidence.
description:
    <http://hedgehog.qa/ Hedgehog> automatically generates a comprehensive array
    of test cases, exercising your software in ways human testers would never
    imagine.

    Generate hundreds of test cases automatically, exposing even the
    most insidious of corner cases. Failures are automatically simplified, giving
    developers coherent, intelligible error messages.

    To get started quickly, see the <https://github.com/hedgehogqa/haskell-hedgehog/tree/master/hedgehog-example examples>.

category:             Testing
abi:                  4e31032d1ca63add8f1865e8e6b57eb4
exposed:              True
exposed-modules:
    Hedgehog Hedgehog.Gen Hedgehog.Internal.Barbie
    Hedgehog.Internal.Config Hedgehog.Internal.Discovery
    Hedgehog.Internal.Distributive Hedgehog.Internal.Exception
    Hedgehog.Internal.Gen Hedgehog.Internal.HTraversable
    Hedgehog.Internal.Opaque Hedgehog.Internal.Prelude
    Hedgehog.Internal.Property Hedgehog.Internal.Queue
    Hedgehog.Internal.Range Hedgehog.Internal.Region
    Hedgehog.Internal.Report Hedgehog.Internal.Runner
    Hedgehog.Internal.Seed Hedgehog.Internal.Show
    Hedgehog.Internal.Shrink Hedgehog.Internal.Source
    Hedgehog.Internal.State Hedgehog.Internal.TH Hedgehog.Internal.Tree
    Hedgehog.Internal.Tripping Hedgehog.Main Hedgehog.Range

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hedgehog-1.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hedgehog-1.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hedgehog-1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hedgehog
hs-libraries:         HShedgehog-1.4-1tCtDh3TfwVEMNETK0R6iC
depends:
    ansi-terminal-1.0.2-HBeoENQnxizF4CvHZENnzA
    async-2.2.5-G01HdI4hTJCBY7T6N2YLEE
    barbies-2.1.0.0-EMhgPtihbMeKX1CsrKKz2Z base-4.17.2.1
    bytestring-0.11.5.3
    concurrent-output-1.10.21-H4MshhyWb1p8muWRzWK1Aq containers-0.6.7
    deepseq-1.4.8.0 directory-1.3.7.1
    erf-2.0.0.0-Eu7AY88UyC43DyrUue97pz exceptions-0.10.5
    lifted-async-0.10.2.7-1iSPSMitj23CxwzY9LLu1E
    mmorph-1.2.1-Dj3j5073UbJL5k7iF3E3ML
    monad-control-1.0.3.1-A4IAQIGkES44eARmeUYssL mtl-2.2.2
    pretty-show-1.10-Ey6CADemQl3EFi7OIHqHDp
    primitive-0.9.1.0-IzoEy6gcvXy7FAbkwCq547
    random-1.2.1.3-6W1EVTTDyQHT39k7sQsHZ
    resourcet-1.2.6-9fR7QYGqUsnJuYWUDOqi5O
    safe-exceptions-0.1.7.4-1geoqNZA39lJ96Kmo3mgOr stm-2.5.1.0
    template-haskell-2.19.0.0 text-2.0.2 time-1.12.2
    transformers-0.5.6.2 transformers-base-0.4.6-BxWaKKyao2EKzvnDCf8sIA
    wl-pprint-annotated-0.1.0.1-JpuMHqlqpCe16HlIGSZJuW

haddock-interfaces:   /usr/share/doc/haskell-hedgehog/html/hedgehog.haddock
haddock-html:         /usr/share/doc/haskell-hedgehog/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hedgehog-1.4-54-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hedgehog
version:              1.4
visibility:           public
id:                   hedgehog-1.4-BEHFvW8abAHCGPjGdSNvkk
key:                  hedgehog-1.4-BEHFvW8abAHCGPjGdSNvkk
license:              BSD-3-Clause
maintainer:           Jacob Stanley <jacob@stanley.io>
author:               Jacob Stanley
homepage:             https://hedgehog.qa
synopsis:             Release with confidence.
description:
    <http://hedgehog.qa/ Hedgehog> automatically generates a comprehensive array
    of test cases, exercising your software in ways human testers would never
    imagine.

    Generate hundreds of test cases automatically, exposing even the
    most insidious of corner cases. Failures are automatically simplified, giving
    developers coherent, intelligible error messages.

    To get started quickly, see the <https://github.com/hedgehogqa/haskell-hedgehog/tree/master/hedgehog-example examples>.

category:             Testing
abi:                  71b155268e91fcc89c3dca98e67b75ba
exposed:              True
exposed-modules:
    Hedgehog Hedgehog.Gen Hedgehog.Internal.Barbie
    Hedgehog.Internal.Config Hedgehog.Internal.Discovery
    Hedgehog.Internal.Distributive Hedgehog.Internal.Exception
    Hedgehog.Internal.Gen Hedgehog.Internal.HTraversable
    Hedgehog.Internal.Opaque Hedgehog.Internal.Prelude
    Hedgehog.Internal.Property Hedgehog.Internal.Queue
    Hedgehog.Internal.Range Hedgehog.Internal.Region
    Hedgehog.Internal.Report Hedgehog.Internal.Runner
    Hedgehog.Internal.Seed Hedgehog.Internal.Show
    Hedgehog.Internal.Shrink Hedgehog.Internal.Source
    Hedgehog.Internal.State Hedgehog.Internal.TH Hedgehog.Internal.Tree
    Hedgehog.Internal.Tripping Hedgehog.Main Hedgehog.Range

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hedgehog-1.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hedgehog-1.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hedgehog-1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hedgehog
hs-libraries:         HShedgehog-1.4-BEHFvW8abAHCGPjGdSNvkk
depends:
    ansi-terminal-1.0.2-GMfU0IJ80BpJLoxPRZMG7V
    async-2.2.5-KcBItHJGOZL2FAQS48vqcn
    barbies-2.1.0.0-7sAbaJb9Jdb6VRihtbtLzr base-4.17.2.1
    bytestring-0.11.5.3
    concurrent-output-1.10.21-LObPEXtezXGFNxvsHUKZcv containers-0.6.7
    deepseq-1.4.8.0 directory-1.3.7.1
    erf-2.0.0.0-Eu7AY88UyC43DyrUue97pz exceptions-0.10.5
    lifted-async-0.10.2.7-GXjYTsSNQPIke80MBCy0s
    mmorph-1.2.1-Dj3j5073UbJL5k7iF3E3ML
    monad-control-1.0.3.1-3LLy3Mh8aXAIWrcnISzEs0 mtl-2.2.2
    pretty-show-1.10-Ey6CADemQl3EFi7OIHqHDp
    primitive-0.9.1.0-DCQZIOwgrIsJjCTNFajhDh
    random-1.2.1.3-FtBkzNFMEVVAWMk0jeYogw
    resourcet-1.2.6-FgkveozFgci6lXOLCU6nL
    safe-exceptions-0.1.7.4-20evycyd2GK9HHUprDldb6 stm-2.5.1.0
    template-haskell-2.19.0.0 text-2.0.2 time-1.12.2
    transformers-0.5.6.2 transformers-base-0.4.6-8PLbLN0z4cRFaAru9ySoP6
    wl-pprint-annotated-0.1.0.1-L32oYqYI6GC6CWwwy1cyOI

haddock-interfaces:   /usr/share/doc/haskell-hedgehog/html/hedgehog.haddock
haddock-html:         /usr/share/doc/haskell-hedgehog/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
